securitysettings/eapqtdialogs/inc/eapquerydialog.h
changeset 36 c98682f98478
parent 34 ad1f037f1ac2
--- a/securitysettings/eapqtdialogs/inc/eapquerydialog.h	Thu Jun 24 11:23:08 2010 +0300
+++ b/securitysettings/eapqtdialogs/inc/eapquerydialog.h	Fri Jul 09 10:14:51 2010 +0300
@@ -11,24 +11,38 @@
 *
 * Contributors:
 *
-* Description: EAP query Dialog
+* Description: EAP Challenge query Dialog
 *
 */
 
 /*
- * %version: 2 %
+ * %version: 3 %
  */
  
 #ifndef __EAPQUERYDIALOG_H__
 #define __EAPQUERYDIALOG_H__
 
-
+// System includes
 #include <HbMessageBox>
 #include <hbdevicedialoginterface.h>
 
+// User includes
+
+// Forward declarations
 class HbTranslator;
 class EapQtValidator;
 
+// External data types
+
+// Constants
+
+/*!
+   @addtogroup group_query_dialog
+   @{
+ */
+
+// Class declaration
+
 class EapQueryDialog: public HbMessageBox, public HbDeviceDialogInterface
     {
     Q_OBJECT
@@ -43,17 +57,18 @@
         void createDialog(const QVariantMap &parameters );
         
         /* Device dialog parameters to be set while dialog is displayed.
-         * Not supported.
+         * Not supported. (from HbDeviceDialogInterface)
          */
         bool setDeviceDialogParameters(const QVariantMap &parameters);
         
-        /* Not supported */
+        /* Not supported. (from HbDeviceDialogInterface) */
         int deviceDialogError() const;
         
         /* Closes the device dialog */
         void closeDeviceDialog(bool byClient);
         
-        /* Returns a pointer to this dialog widget */
+        /* Returns a pointer to this dialog widget.
+           (from HbDeviceDialogInterface) */
         HbPopup *deviceDialogWidget() const;
                 
     signals:
@@ -74,13 +89,17 @@
                 
         Q_DISABLE_COPY(EapQueryDialog)
    
-    private:
+    private: // data
+        // NOT OWNED
         
-        /* Pointer to the HbTranslator */
+        // OWNED      
+        //! Pointer to the HbTranslator
         QScopedPointer<HbTranslator> mTranslator;
         
-        /* Tells whether Ok Action has already been pressed */
+        //! Tells whether Ok Action has already been pressed
         bool mOkActionPressed;
     };
+    
+/*! @} */
 
 #endif // __EAPQUERYDIALOG_H__
@@ -43,17 +57,18 @@
         int deviceDialogError() const;
         
-        /* Closes the device dialog */
+        /* Closes the device dialog. (from HbDeviceDialogInterface) */
         void closeDeviceDialog(bool byClient);
         